#	Loren Williams
#	Georgia Tech
#	Trypsin Pymol script
#	
#-----------------------------------------------------------------------------
## Header: General Commands ##

# delete all objects and reset pymol
reinitialize
# set the background color to white
bg_color white
# make the background transparent for ray trace 
set ray_opaque_background, 0
# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2
# turn off shadows during ray trace
set ray_shadows, 0
# set the mouse mode for desktop.
config_mouse three_button
# get rid of double bonds and skinny bonds to H
set stick_h_scale, 1
set valence, 0
# high quality surfaces
set surface_quality, 3

#----------------------------------------
#
load files/4ktuFH.pdb, trypsin_free
unset ribbon_color, (*)
set ribbon_color, default
for name in cmd.get_object_list(): \
  cmd.spectrum(selection=name + " and polymer")

load files/1max.pdb, trypsin_zap
load files/2ptc.pdb, trypsin_bpti
align trypsin_free, trypsin_zap
align trypsin_bpti, trypsin_zap

hide everything, *
show cartoon, *
color blue, name N*
color red, name O*
color gray90, name H*
remove name HA

remove resn hoh



#-----Catalytic Triad

create cat_triad_free, trypsin_free and (resi 57+102+195+189) and chain A
remove cat_triad_free and (name O+N+C)
hide everything, cat_triad_free
show spheres, cat_triad_free and name Og and resi 57
alter cat_triad_free and name OG and resi 195, vdw=.4 
rebuild
color wheat, name C* and cat_triad_free
color gray90, name H* and cat_triad_free
show sticks, cat_triad_free
show spheres, cat_triad_free and name OG and resi 195
distance hbond1, (name HD1 and cat_triad_free), (name OD2 and cat_triad_free), 3.4
distance hbond1, (name NE2 and cat_triad_free), (name HG and cat_triad_free), 3.4

#-----Michaelis Complex
create Michaelis_Complex,  trypsin_bpti and chain I and (resi 15+16+17) or (cat_triad_free ) 
hide everything, Michaelis_Complex
show sticks, Michaelis_Complex
show spheres, Michaelis_Complex and name C and resi 15
alter Michaelis_Complex and name C and resi 15, vdw=.4 
show spheres, Michaelis_Complex and resi 195 and name OG
alter Michaelis_Complex and name OG and resi 195, vdw=.4 
rebuild

color wheat, name C* and Michaelis_Complex
color green, name C* and Michaelis_Complex and (resi 57+195+102)
color cyan, Michaelis_Complex and name C and resi 15

#-----Tetrahedral intermediate

create tet_intermediate, ( trypsin_zap and (resi 195 and (name Og+CB+CA) ) or (resi 247 and (name O2P+O1P+P) or (Michaelis_Complex and resi 15 and not (name O+C)) )) (or Michaelis_Complex and (resi 16 and not name N) or resi 17) or (cat_triad_free and resi 57+102+189)
remove tet_intermediate and resn val
bond tet_intermediate and name CA and resi 15, tet_intermediate and name P
bond tet_intermediate and name O1P, tet_intermediate and name CA and resi 16
h_add name NE2 and resi 57 and tet_intermediate

alter tet_intermediate and name OG and resi 195, vdw=.4 
alter tet_intermediate and name P and resi 247, vdw=.4 
rebuild
hide everything, tet_intermediate
show spheres, tet_intermediate and name OG and resi 195
show spheres, tet_intermediate and name P and resi 247

color wheat, name C* and tet_intermediate
color green, name C* and tet_intermediate and (resi 57+195+102+189)
color cyan, tet_intermediate and name P
show stick, tet_intermediate 

distance hbond2, (name OD2 and tet_intermediate), (name HD1 and tet_intermediate), 2.4


# You clicked /tet_intermediate//A/ASP`102/OD2
# You clicked /tet_intermediate//A/HIS`57/HD1


#list_hb tet_intermediat and resi 57, tet_intermediate and (resi 102 and name OD2) or resi 15, cutoff=4, angle= 35, hb_list_name = hbonds_tet_intermediate


#-----Oxyanion Hole

create oxy_anion_hole, trypsin_free and ((resi 195) or (resi 194)  or (resi 193) or (resi 192)) or (tet_intermediate and resn ZAP and name O2P)
remove oxy_anion_hole and not (name N or name C or name CA or name H or name O or name O2P)
hide everything, oxy_anion_hole
show sticks, oxy_anion_hole 
show sphere, oxy_anion_hole and ((resi 195 and name N) or (resi 194 and name N)  or (resi 193 and name N) or (resn ZAP and name O2P))
show nb_spheres, oxy_anion_hole and (resn ZAP and name O2P)
set sphere_transparency=0.5, oxy_anion_hole
remove /oxy_anion_hole//A/GLN`192/H
remove /oxy_anion_hole//A/GLN`192/N
remove /oxy_anion_hole//A/SER`195/C
remove /oxy_anion_hole//A/SER`195/O
distance hbond3, (oxy_anion_hole and (resn ZAP and name O2P)), (name H and oxy_anion_hole), 3.4



#---------labels---------
label oxy_anion_hole and name O2P, "Oxyanion Hole"
label oxy_anion_hole and name N, "NH"
label cat_triad_free and name CA and resn asp and resi 102, "ASP 102"
label cat_triad_free and name CA and resn his and resi 57, "HIS 57"
label cat_triad_free and name CB and resn ser and resi 195, "SER 195"
label cat_triad_free and name OD1 and resn asp and resi 189, "SPECIFICITY POCKET"

set label_position, (-0.5,-1.5,3), oxy_anion_hole
set label_position, (0,1.5,3), cat_triad_free
set label_position, (-0.5,2,3), tet_intermediate
set label_position, (-0.5,2,3), Michaelis_Complex
color black, hbonds_*

set label_size, -0.0, hbond*

set label_size, -0.60, oxy_anion_hole
set label_size, -0.60, cat_triad_free
set label_size, -0.60, tet_intermediate
set label_size, -0.60, Michaelis_Complex

set dash_width, 3.0, hbond*
set dash_gap, 0.30, hbond*
set dash_color, black, hbond*
#set label_position, (1.2,0,0), hbond*

#------------------------------------------

#delete trypsin_free
remove not chain A and trypsin_free
delete trypsin_zap
delete trypsin_bpti

disable all
set_view (\
    -0.963521779,   -0.173941627,   -0.203315258,\
    -0.266690344,    0.685807049,    0.677137792,\
     0.021652922,    0.706671119,   -0.707189679,\
     0.000255437,   -0.000684078,  -40.037406921,\
     3.817333698,   15.911974907,   21.458703995,\
    28.605455399,   51.486732483,  -20.000000000 )
### cut above here and paste into script ###

enable trypsin_free
enable cat_triad_free
enable hbond1
#ray 1400,1000
#save files/images/cat_triad_free_view2.png

#enable oxy_anion_hole
#ray 1400,1000
#save files/images/cat_triad_free_oxyhole_view2.png

#disable all
#enable Michaelis_Complex
#enable hbonds_cat_triad_free
#ray 1400,1000
#save files/images/Michaelis_Complex_view2.png

#enable oxy_anion_hole
#ray 1400,1000
#save files/images/Michaelis_Complex_oxyhole_view2.png

#disable all
#enable tet_intermediate
#enable hbonds_tet_intermediate
#ray 1400,1000
#save files/images/tet_intermediate_view2.png

#enable oxy_anion_hole
#ray 1400,1000
#save files/images/tet_intermediate_oxyhole_view2.png

